==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateRunningFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ContainerStateRunningFluentImpl<A extends ContainerStateRunningFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStateRunningFluent<A>{

    private String startedAt;

    public ContainerStateRunningFluentImpl(){
    }
    public ContainerStateRunningFluentImpl(ContainerStateRunning instance){
            this.withStartedAt(instance.getStartedAt()); 
    }

    public String getStartedAt(){
            return this.startedAt;
    }

    public A withStartedAt(String startedAt){
            this.startedAt=startedAt; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerStateRunningFluentImpl that = (ContainerStateRunningFluentImpl) o;
            if (startedAt != null ? !startedAt.equals(that.startedAt) :that.startedAt != null) return false;
            return true;
    }




}

==> kubernetes-model-4.2.2-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateRunningFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ContainerStateRunningFluentImpl<A extends ContainerStateRunningFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStateRunningFluent<A>{

    private String startedAt;

    public ContainerStateRunningFluentImpl(){
    }
    public ContainerStateRunningFluentImpl(ContainerStateRunning instance){
            this.withStartedAt(instance.getStartedAt()); 
    }

    public String getStartedAt(){
            return this.startedAt;
    }

    public A withStartedAt(String startedAt){
            this.startedAt=startedAt; return (A) this;
    }

    public Boolean hasStartedAt(){
            return this.startedAt != null;
    }

    public A withNewStartedAt(String arg1){
            return (A)withStartedAt(new String(arg1));
    }

    public A withNewStartedAt(StringBuilder arg1){
            return (A)withStartedAt(new String(arg1));
    }

    public A withNewStartedAt(StringBuffer arg1){
            return (A)withStartedAt(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerStateRunningFluentImpl that = (ContainerStateRunningFluentImpl) o;
            if (startedAt != null ? !startedAt.equals(that.startedAt) :that.startedAt != null) return false;
            return true;
    }




}
